# neuromodels
[![PyPi version](https://img.shields.io/pypi/v/neuromodels.svg)](https://pypi.python.org/pypi/neuromodels)
[![python compatibility](https://img.shields.io/pypi/pyversions/neuromodels.svg)](https://pypi.python.org/pypi/neuromodels)
[![Documentation Status](https://readthedocs.org/projects/neuromodels/badge/?version=latest)](https://neuromodels.readthedocs.io/en/latest/?badge=latest)
[![Tests](https://github.com/nicolossus/neuromodels/workflows/Tests/badge.svg?branch=main)](https://github.com/nicolossus/neuromodels/actions)
[![codecov](https://codecov.io/gh/nicolossus/neuromodels/branch/main/graph/badge.svg)](https://codecov.io/gh/nicolossus/neuromodels)
[![GitHub license](https://img.shields.io/badge/License-MIT-blue.svg)](https://github.com/nicolossus/neuromodels/blob/master/LICENSE)

Computational neuroscience models and analysis tools.

Some more text..
